pub fn create_ctx() -> Option<Context>Expand description
Creates the libsais context that allows reusing allocated memory with each libsais operation.
In multi-threaded environments, use one context per thread for parallel executions.
Returns the context, or None on allocation failure.