pub fn create_ctx_omp(threads: SaSint) -> Option<Context>Expand description
Creates the libsais context for parallel operations using OpenMP-style threading.
In multi-threaded environments, use one context per thread for parallel executions.
threads: number of worker threads (can be 0 for the implementation default).
Returns the context, or None on allocation failure.