create_ctx_omp

Function create_ctx_omp 

pub fn create_ctx_omp(threads: SaSint) -> Option<Context>
Creates the libsais context that allows reusing allocated memory with each parallel libsais operation using OpenMP. In multi-threaded environments, use one context per thread for parallel executions.

Arguments

  • threads: The number of OpenMP threads to use (can be 0 for OpenMP default).

Returns

the libsais context, NULL otherwise.